@@ -41,8 +41,8 @@
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
 
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 
 #include <libgnomevfs/gnome-vfs-utils.h>
 
@@ -119,6 +119,7 @@ typedef struct {
 	int display_height;
 	int max_item_count;
 	uint update_interval;
+	int update_timeout;
 	
 	EelScalableFont *font;	
 	EelScalableFont *bold_font;	
@@ -126,6 +127,7 @@ typedef struct {
 	gboolean news_changed;
 	gboolean always_display_title;
 	gboolean configure_mode;
+	gboolean opened;
 		
 	guint timer_task;
 } News;
@@ -203,6 +205,8 @@ static char *news_get_indicator_image   (News *news_data);
 static void nautilus_news_free_channel_list (News *news_data);
 static gboolean nautilus_news_save_channel_state (News* news_data);
 static void update_size_and_redraw (News* news_data);
+static void queue_update_size_and_redraw (News* news_data);
+
 static char* get_xml_path (const char *file_name, gboolean force_local);
 static int check_for_updates (gpointer callback_data);
 static RSSChannelData* get_channel_from_name (News *news_data, const char *channel_name);
@@ -244,8 +248,8 @@ get_bonobo_properties (BonoboPropertyBag *bag,
                 break;
         }
         case CLOSE_NOTIFY: {
-		/* this shouldn't be read, but return FALSE anyway */
-		BONOBO_ARG_SET_BOOLEAN (arg, FALSE);
+		/* this shouldn't be read, but return it anyway */
+		BONOBO_ARG_SET_BOOLEAN (arg, news->opened);
 		break;
 	}
 	
@@ -274,9 +278,14 @@ set_bonobo_properties (BonoboPropertyBag *bag,
  
  	/* when closed, clear the changed flags; also, exit configure mode */
         case CLOSE_NOTIFY: {
-		nautilus_news_clear_changed_flags (news);
-		news->configure_mode = FALSE;
-		set_views_for_mode (news);
+		if (BONOBO_ARG_GET_BOOLEAN (arg)) {
+			news->opened = FALSE;
+			nautilus_news_clear_changed_flags (news);
+			news->configure_mode = FALSE;
+			set_views_for_mode (news);
+		} else {
+			news->opened = TRUE;
+		}
 		break;
 	}
 	
@@ -307,6 +316,11 @@ do_destroy (GtkObject *obj, News *news)
 		news->timer_task = 0;
 	}
 
+	if (news->update_timeout > 0) {
+		gtk_timeout_remove (news->update_timeout);
+		news->update_timeout = -1;
+	}
+	
         if (news->closed_triangle != NULL) {
 		gdk_pixbuf_unref (news->closed_triangle);
 	}
@@ -333,6 +347,11 @@ do_destroy (GtkObject *obj, News *news)
 	
 	/* free all the channel data */
 	nautilus_news_free_channel_list (news);
+
+	/* free the property bag */
+	if (news->property_bag != NULL) {
+		bonobo_object_unref (BONOBO_OBJECT (news->property_bag));
+	}
 	
 	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_NEWS_MAX_ITEMS,
                                          max_items_changed,
@@ -423,7 +442,7 @@ draw_rss_logo_image (RSSChannelData *channel_data,
 		     int offset,
 		     gboolean measure_only)
 {
-	char time_str[16];
+	char *time_str;
 	int logo_width, logo_height;
 	int v_offset, pixbuf_width;
 	int time_x_pos, time_y_pos;
@@ -452,7 +471,7 @@ draw_rss_logo_image (RSSChannelData *channel_data,
 
 		/* also, draw the update time in the upper right corner if it fits*/
 		if (channel_data->last_update != 0 && !measure_only) {
-			strftime (&time_str[0], 16, "%I:%M %p",	localtime (&channel_data->last_update));
+			time_str = eel_strdup_strftime (_("%I:%M %p"), localtime (&channel_data->last_update));
 
 			time_dimensions = eel_scalable_font_measure_text (channel_data->owner->font, 9, time_str, strlen (time_str));
 	
@@ -466,6 +485,7 @@ draw_rss_logo_image (RSSChannelData *channel_data,
 							     TIME_FONT_SIZE, time_str, strlen (time_str),
 							     EEL_RGB_COLOR_BLACK, EEL_OPACITY_FULLY_OPAQUE);
 			}
+			g_free (time_str);
 		}
 	}
 	return v_offset;
@@ -612,7 +632,8 @@ draw_rss_items (RSSChannelData *channel_data,
 				}	
 			}
 		}
-		gtk_object_destroy (GTK_OBJECT (smooth_text_layout));
+
+		gtk_object_unref (GTK_OBJECT (smooth_text_layout));
 		
 		item_data->item_end_y = item_data->item_start_y + text_dimensions.height;
 		v_offset += text_dimensions.height + 4;
@@ -1115,7 +1136,7 @@ rss_logo_callback (GnomeVFSResult  error, GdkPixbuf *pixbuf, gpointer callback_d
 		gdk_pixbuf_ref (pixbuf);
 		pixbuf = eel_gdk_pixbuf_scale_down_to_fit (pixbuf, 192, 40);		
 		channel_data->logo_image = pixbuf;
-		update_size_and_redraw (channel_data->owner);
+		queue_update_size_and_redraw (channel_data->owner);
 	}
 }
 
@@ -1212,6 +1233,30 @@ update_size_and_redraw (News* news_data)
 	gtk_widget_queue_draw (news_data->news_display);
 }
 
+/* handle the timeout firing by updating and redrawing */
+static int
+update_timeout_callback (gpointer callback_data)
+{
+	News *news_data;
+	news_data = (News*) callback_data;
+
+	news_data->update_timeout = -1;	
+	update_size_and_redraw (news_data);
+	return 0;
+}
+
+/* utility routine to queue an update for the future, so many quick ones get coalesced */
+static void
+queue_update_size_and_redraw (News* news_data)
+{
+	/* if there already is one pending, simply return */
+	if (news_data->update_timeout > 0) {
+		return;
+	}
+	
+	news_data->update_timeout = gtk_timeout_add (1500, update_timeout_callback, news_data);
+}
+
 /* utility routine to search for the passed-in url in an item list */
 static gboolean
 has_matching_uri (GList *items, const char *target_uri, gboolean *old_changed_flag)
@@ -1501,7 +1546,7 @@ rss_read_done_callback (GnomeVFSResult result,
 	 * schedule a redraw.
 	 */
 	if (changed_count > 0) {
-		update_size_and_redraw (channel_data->owner); 
+		queue_update_size_and_redraw (channel_data->owner); 
 	}
 }
 
@@ -1636,6 +1681,7 @@ read_channel_list (News *news_data)
 {
 	char *path;
 	xmlDocPtr channel_doc;
+
 	/* free the old channel data, if any  */
 	nautilus_news_free_channel_list (news_data);
 	
@@ -1648,7 +1694,7 @@ read_channel_list (News *news_data)
 			nautilus_news_add_channels (news_data, channel_doc);
 			xmlFreeDoc (channel_doc);
 		}
-	g_free (path);
+                g_free (path);
 	}
 }
 
@@ -2021,7 +2067,11 @@ nautilus_news_load_location (NautilusView *view, const char *location, News *new
 {
 	g_free (news->uri);
 	news->uri = g_strdup (location);
-	update_size_and_redraw (news);
+	
+	/* only do work if we're open */
+	if (news->opened) {
+		update_size_and_redraw (news);
+	}
 }
 
 /* utility routine to determine the sort position of a checkbox */
@@ -2223,8 +2273,7 @@ make_remove_widgets (News *news, GtkWidget *container)
 	news->remove_button = gtk_button_new_with_label (_("Remove Site"));
 	gtk_container_add (GTK_CONTAINER (button_box), news->remove_button);
 	gtk_signal_connect (GTK_OBJECT (news->remove_button), "clicked",
-		(GtkSignalFunc) remove_selected_site, news);
-
+                            (GtkSignalFunc) remove_selected_site, news);
 }
 
 /* generate the add new site widgets */
@@ -2422,7 +2471,8 @@ make_news_view (const char *iid, gpointer callback_data)
 	/* get preferences and sanity check them */
 	news->max_item_count = eel_preferences_get_integer (NAUTILUS_PREFERENCES_NEWS_MAX_ITEMS);
 	news->update_interval = 60 * eel_preferences_get_integer (NAUTILUS_PREFERENCES_NEWS_UPDATE_INTERVAL);	
-	
+	news->update_timeout = -1;
+		
 	if (news->max_item_count <= 0) {
 		news->max_item_count = 2;		
 	}
@@ -2453,7 +2503,7 @@ make_news_view (const char *iid, gpointer callback_data)
 	news->property_bag = bonobo_property_bag_new (get_bonobo_properties,  set_bonobo_properties, news);
 	bonobo_control_set_properties (nautilus_view_get_bonobo_control (news->view), news->property_bag);
 	bonobo_property_bag_add (news->property_bag, "tab_image", TAB_IMAGE, BONOBO_ARG_STRING, NULL,
-				 "image indicating that the news has changed", 0);
+				 _("image indicating that the news has changed"), 0);
 	bonobo_property_bag_add (news->property_bag, "close", CLOSE_NOTIFY,
 				 BONOBO_ARG_BOOLEAN, NULL, "close notification", 0);
  	
