@@ -39,8 +39,8 @@
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-xml-extensions.h>
 #include <ghttp.h>
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include <gnome.h>
 #include <gtk/gtkeventbox.h>
 #include <libgnome/gnome-i18n.h>
@@ -59,7 +59,7 @@
 #define MAX_FILE_SIZE	1024*1024
 #define MAX_SELECTION_SIZE 256
 
-#define ADDITIONAL_SERVICES_MENU_PATH	"/menu/Services Placeholder/Services/Service Items"
+#define ADDITIONAL_SERVICES_MENU_PATH	"/menu/Text view/Services Placeholder"
 
 #define NAUTILUS_PREFERENCES_TEXT_VIEW_FONT                     "components/text_view/font"
 #define NAUTILUS_PREFERENCES_TEXT_VIEW_STANDARD_FONT_SIZE       "components/text_view/standard_font_size"
@@ -328,7 +328,7 @@ file_read_callback (GnomeVFSAsyncHandle *vfs_handle,
                                               callback_data);
                         return;
 		} else {
-                        name = nautilus_file_get_name (text_view->details->file);
+                        name = nautilus_file_get_display_name (text_view->details->file);
                         message = g_strdup_printf (_("Sorry, but %s is too large for Nautilus to load all of it."),
                                                    name);
                         
@@ -763,12 +763,12 @@ merge_bonobo_menu_items (BonoboControl *control, gboolean state, gpointer user_d
 	text_view = NAUTILUS_TEXT_VIEW (user_data);
 
 	if (state) {
-                /* FIXME bugzilla.eazel.com 1274:
+                /* FIXME bugzilla.gnome.org 41274:
                  * See nautilus-text-view-ui.xml.  Need to query system for
                  * available fonts instead of hard coding the font list
                  */
 
-                /* FIXME bugzilla.eazel.com 7907: 
+                /* FIXME bugzilla.gnome.org 47907: 
                  * The "GTK System Font" string is hard coded in many places.
                  * Please see nautilus-text-view-ui.xml.
                  */
