@@ -231,7 +231,7 @@ nautilus_tree_view_insert_model_node (NautilusTreeView *view, NautilusTreeNode *
 	if (parent_view_node == NULL && !nautilus_tree_node_is_toplevel (node)) {
 		register_unparented_node (view, node);
 	} else {
-		text[0] = nautilus_file_get_name (file);
+		text[0] = nautilus_file_get_display_name (file);
 		text[1] = NULL;
 
 		if (nautilus_tree_view_model_node_to_view_node (view, node) == NULL) {
@@ -437,7 +437,7 @@ nautilus_tree_view_update_model_node (NautilusTreeView *view, NautilusTreeNode *
 			(file, "accept", NAUTILUS_ICON_SIZE_FOR_MENUS,
 			 is_anti_aliased (view));
 
-		name = nautilus_file_get_name (file);
+		name = nautilus_file_get_display_name (file);
 	
 		eel_ctree_set_node_info (EEL_CTREE (view->details->tree),
 					 view_node,
@@ -900,7 +900,7 @@ ctree_compare_rows (EelCList *clist,
 		file2 = node2 ? nautilus_tree_node_get_file (node2) : NULL;
 
 		if (file1 != NULL && file2 != NULL) {
-			result = nautilus_file_compare_for_sort (file1, file2, NAUTILUS_FILE_SORT_BY_NAME, FALSE, FALSE);
+			result = nautilus_file_compare_for_sort (file1, file2, NAUTILUS_FILE_SORT_BY_DISPLAY_NAME, FALSE, FALSE);
 		}
 	}
 
@@ -928,7 +928,7 @@ create_tree (NautilusTreeView *view)
 
 	update_smooth_graphics_mode (view);
 
-	/* FIXME bugzilla.eazel.com 6820:
+	/* FIXME bugzilla.gnome.org 46820:
 	 * Using the NautilusFile comparison function to sort by
 	 * is way too slow when opening large directories (those with
 	 * 1000s of files). So to fix bug 6988 we're reverting back
@@ -1357,18 +1357,13 @@ select_current_location (NautilusTreeView *view)
 {
 	cancel_selection_in_progress (view);
 
-	/* FIXME bugzilla.eazel.com 6801: it seems likely that either
-	 * eel_uris_match or eel_uris_match_ignore_fragments
-	 * should be used here.
-	 */
-	if (eel_strcmp (view->details->current_main_view_uri,
-			view->details->selected_uri) == 0) {
-		return;
+	if (view->details->selected_uri == NULL ||
+	    !eel_uris_match_ignore_fragments (view->details->current_main_view_uri,
+					      view->details->selected_uri)) {
+		view->details->in_progress_select_uris = get_uri_sequence_to_root
+			(g_strdup (view->details->current_main_view_uri));
+		expand_uri_sequence_and_select_end (view);
 	}
-
-	view->details->in_progress_select_uris = get_uri_sequence_to_root
-		(g_strdup (view->details->current_main_view_uri));
-	expand_uri_sequence_and_select_end (view);
 }
 
 static void
