@@ -22,7 +22,7 @@
    Boston, MA 02111-1307, USA.
 
    Authors: John Sullivan <sullivan@eazel.com>
-            Darin Adler <darin@eazel.com>
+            Darin Adler <darin@bentspoon.com>
 */
 
 #include <config.h>
