@@ -37,12 +37,12 @@
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <eel/eel-xml-extensions.h>
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include <stdlib.h>
 
 #define NAUTILUS_LINK_GENERIC_TAG	"Link"
@@ -356,10 +356,10 @@ nautilus_link_desktop_file_get_link_name_from_desktop (NautilusDesktopFile *desk
 
 	name = NULL;
 
-	if (nautilus_desktop_file_get_string (desktop_file,
-					      "Desktop Entry",
-					      "Name",
-					      &name)) {
+	if (nautilus_desktop_file_get_locale_string (desktop_file,
+						     "Desktop Entry",
+						     "Name",
+						     &name)) {
 		return name;
 	} else {
 		return NULL;
