@@ -112,7 +112,7 @@ program_file_pair_compute_status (ProgramFilePair *pair)
 {
 	ProgramFileStatus new_status;
 
-	/* FIXME bugzilla.eazel.com 1459: Need to check whether it's the default or in short list for the supertype */
+	/* FIXME bugzilla.gnome.org 41459: Need to check whether it's the default or in short list for the supertype */
 	if (program_file_pair_is_default_for_file_type (pair)) {
 		new_status = PROGRAM_DEFAULT_FOR_TYPE;
 	} else if (program_file_pair_is_default_for_file (pair)) {
@@ -203,7 +203,7 @@ program_file_pair_get_program_name_for_display (ProgramFilePair *pair)
 static char *
 get_supertype_from_file (NautilusFile *file)
 {
-	/* FIXME bugzilla.eazel.com 1459: Needs implementation */
+	/* FIXME bugzilla.gnome.org 41459: Needs implementation */
 	return nautilus_file_get_string_attribute (file, "type");
 }
 
@@ -260,7 +260,7 @@ get_file_name_for_display (NautilusFile *file)
 
 	g_assert (NAUTILUS_IS_FILE (file));
 
-	full_name = nautilus_file_get_name (file);
+	full_name = nautilus_file_get_display_name (file);
 	truncated_name = eel_str_middle_truncate
 		(full_name, MAX_DISPLAYED_FILE_NAME_LENGTH);
 	g_free (full_name);
