@@ -20,7 +20,7 @@
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
   
-   Author: Darin Adler <darin@eazel.com>
+   Author: Darin Adler <darin@bentspoon.com>
 */
 
 #include <config.h>
@@ -126,7 +126,7 @@ real_monitor_add (NautilusFile *file,
 {
 	nautilus_directory_monitor_add_internal
 		(file->details->directory, file,
-		 client, TRUE, TRUE, attributes);
+		 client, TRUE, TRUE, attributes, NULL, NULL);
 }   
 			   
 static void
@@ -146,7 +146,7 @@ real_call_when_ready (NautilusFile *file,
 {
 	nautilus_directory_call_when_ready_internal
 		(file->details->directory, file,
-		 attributes, NULL, callback, callback_data);
+		 attributes, FALSE, NULL, callback, callback_data);
 }
 
 static void
