@@ -79,9 +79,6 @@ static const char untranslated_trash_link_name[] = N_("Trash");
 /* Timeout to check the desktop directory for updates */
 #define RESCAN_TIMEOUT 4000
 
-static char *desktop_directory;
-static time_t desktop_dir_modify_time;
-
 struct FMDesktopIconViewDetails
 {
 	BonoboUIComponent *ui;
@@ -90,6 +87,7 @@ struct FMDesktopIconViewDetails
 	/* For the desktop rescanning
 	 */
 	guint delayed_init_signal;
+	guint done_loading_signal;
 	guint reload_desktop_timeout;
 	gboolean pending_rescan;
 };
@@ -111,11 +109,6 @@ static void     volume_mounted_callback                           (NautilusVolum
 static void     volume_unmounted_callback                         (NautilusVolumeMonitor  *monitor,
 								   NautilusVolume         *volume,
 								   FMDesktopIconView      *icon_view);
-static void     icon_view_handle_uri_list                   	  (NautilusIconContainer  *container,
-								   const char             *item_uris,
-								   int                     x,
-								   int                     y,
-								   FMDirectoryView        *view);
 static int      desktop_icons_compare_callback                    (NautilusIconContainer  *container,
 								   NautilusFile           *file_a,
 								   NautilusFile           *file_b,
@@ -131,10 +124,19 @@ static void     update_disks_menu                                 (FMDesktopIcon
 static void     free_volume_black_list                            (FMDesktopIconView      *view);
 static gboolean	volume_link_is_selection 			  (FMDirectoryView 	  *view);
 
-
 EEL_DEFINE_CLASS_BOILERPLATE (FMDesktopIconView,
-				   fm_desktop_icon_view,
-				   FM_TYPE_ICON_VIEW)
+			      fm_desktop_icon_view,
+			      FM_TYPE_ICON_VIEW)
+
+static char *desktop_directory;
+static time_t desktop_dir_modify_time;
+
+static void
+desktop_directory_changed_callback (gpointer callback_data)
+{
+	g_free (desktop_directory);
+	desktop_directory = nautilus_get_desktop_directory ();
+}
 
 static NautilusIconContainer *
 get_icon_container (FMDesktopIconView *icon_view)
@@ -236,6 +238,17 @@ fm_desktop_icon_view_destroy (GtkObject *object)
 	if (icon_view->details->reload_desktop_timeout != 0) {
 		gtk_timeout_remove (icon_view->details->reload_desktop_timeout);
 	}
+
+	if (icon_view->details->done_loading_signal != 0) {
+		gtk_signal_disconnect (GTK_OBJECT (fm_directory_view_get_model
+						   (FM_DIRECTORY_VIEW (icon_view))),
+				       icon_view->details->done_loading_signal);
+	}
+
+	if (icon_view->details->delayed_init_signal != 0) {
+		gtk_signal_disconnect (GTK_OBJECT (icon_view),
+				       icon_view->details->delayed_init_signal);
+	}
 	
 	/* Delete all of the link files. */
 	delete_all_mount_links ();
@@ -332,7 +345,7 @@ volume_in_black_list (FMDesktopIconView *icon_view,
 	g_return_val_if_fail (FM_IS_DESKTOP_ICON_VIEW (icon_view), TRUE);
 
 	for (p = icon_view->details->mount_black_list; p != NULL; p = p->next) {
-		if (strcmp ((char *) p->data, volume->mount_path) == 0) {
+		if (strcmp ((char *) p->data, nautilus_volume_get_mount_path (volume)) == 0) {
 			return TRUE;
 		}
 	}
@@ -356,7 +369,7 @@ create_unique_volume_name (const NautilusVolume *volume)
 	 */	   
 	index = 1;
 			
-	volume_name = nautilus_volume_monitor_get_volume_name (volume);	
+	volume_name = nautilus_volume_get_name (volume);	
 		
 	uri_path = g_strdup_printf ("%s/%s", desktop_directory, volume_name);		
 	uri = gnome_vfs_uri_new (uri_path);
@@ -380,7 +393,7 @@ create_unique_volume_name (const NautilusVolume *volume)
 		volume_name = new_name;	
 	}
 	
-	original_volume_name = nautilus_volume_monitor_get_volume_name (volume);
+	original_volume_name = nautilus_volume_get_name (volume);
 	if (strcmp (volume_name, original_volume_name) != 0) {
 		nautilus_volume_monitor_set_volume_name (nautilus_volume_monitor_get (),
 							 volume, volume_name);
@@ -404,23 +417,19 @@ create_mount_link (FMDesktopIconView *icon_view,
 		return;
 	}
 	
-	/* FIXME bugzilla.eazel.com 5412: Design a comprehensive desktop mounting strategy */
-	if (!nautilus_volume_monitor_volume_is_removable (volume)) {
+	/* FIXME bugzilla.gnome.org 45412: Design a comprehensive desktop mounting strategy */
+	if (!nautilus_volume_is_removable (volume)) {
 		return;
 	}
 
 	/* Get icon type */
-	switch (volume->device_type) {
+	icon_name = "i-blockdev";
+	switch (nautilus_volume_get_device_type (volume)) {
 	case NAUTILUS_DEVICE_AUDIO_CD:
-	case NAUTILUS_DEVICE_CD_ROM_DRIVE:
+	case NAUTILUS_DEVICE_CDROM_DRIVE:
 		icon_name = "i-cdrom";
 		break;
 
-	case NAUTILUS_DEVICE_CAMERA:
-		icon_name = "i-blockdev";
-		break;
-
-		
 	case NAUTILUS_DEVICE_FLOPPY_DRIVE:
 		icon_name = "i-floppy";
 		break;
@@ -441,15 +450,12 @@ create_mount_link (FMDesktopIconView *icon_view,
 		icon_name = "i-zipdisk";
 		break;
 
+	case NAUTILUS_DEVICE_CAMERA:
 	case NAUTILUS_DEVICE_UNKNOWN:
-		icon_name = "i-blockdev";
-		break;	
-	default:
-		icon_name = "i-blockdev";
-		break;	
+		break;
 	}
 
-	target_uri = nautilus_volume_monitor_get_target_uri (volume);
+	target_uri = nautilus_volume_get_target_uri (volume);
 	
 	volume_name = create_unique_volume_name (volume);
 	
@@ -527,10 +533,11 @@ static void
 delayed_init (FMDesktopIconView *desktop_icon_view)
 {
 	/* Keep track of the load time. */
-	gtk_signal_connect (GTK_OBJECT (fm_directory_view_get_model
-					(FM_DIRECTORY_VIEW (desktop_icon_view))),
-			    "done_loading",
-			    GTK_SIGNAL_FUNC (done_loading), desktop_icon_view);
+	desktop_icon_view->details->done_loading_signal = 
+		gtk_signal_connect (GTK_OBJECT (fm_directory_view_get_model
+						(FM_DIRECTORY_VIEW (desktop_icon_view))),
+				    "done_loading",
+				    GTK_SIGNAL_FUNC (done_loading), desktop_icon_view);
 
 	/* Monitor desktop directory. */
 	desktop_icon_view->details->reload_desktop_timeout =
@@ -551,7 +558,10 @@ fm_desktop_icon_view_initialize (FMDesktopIconView *desktop_icon_view)
 	GtkAdjustment *hadj, *vadj;
 
 	if (desktop_directory == NULL) {
-		desktop_directory = nautilus_get_desktop_directory ();
+		eel_preferences_add_callback (NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
+					      desktop_directory_changed_callback,
+					      NULL);
+		desktop_directory_changed_callback (NULL);
 	}
 
 	icon_container = get_icon_container (desktop_icon_view);
@@ -636,11 +646,6 @@ fm_desktop_icon_view_initialize (FMDesktopIconView *desktop_icon_view)
 					desktop_icon_view,
 					GTK_OBJECT (desktop_icon_view));
 	
-	gtk_signal_connect (GTK_OBJECT (icon_container),
-			    "handle_uri_list",
-			    GTK_SIGNAL_FUNC (icon_view_handle_uri_list),
-			    desktop_icon_view);
-
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_HOME_URI,
 					   home_uri_changed,
 				  	   desktop_icon_view);
@@ -796,7 +801,6 @@ fm_desktop_icon_view_trash_state_changed_callback (NautilusTrashMonitor *trash_m
 
 	path = nautilus_make_path (desktop_directory, TRASH_LINK_NAME);
 
-	/* Change the XML file to have a new icon. */
 	nautilus_link_local_set_icon (path, state ? "trash-empty" : "trash-full");
 
 	g_free (path);
@@ -838,7 +842,7 @@ volume_unmounted_callback (NautilusVolumeMonitor *monitor,
 
 	g_assert (volume != NULL);
 	
-	volume_name = nautilus_volume_monitor_get_volume_name (volume);
+	volume_name = nautilus_volume_get_name (volume);
 	if (volume_name == NULL) {
 		return;
 	}
@@ -850,70 +854,6 @@ volume_unmounted_callback (NautilusVolumeMonitor *monitor,
 	g_free (link_path);
 }
 
-static void
-icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_uris,
-			   int x, int y, FMDirectoryView *view)
-{
-	GList *uri_list, *node;
-	GnomeDesktopEntry *entry;
-	GdkPoint point;
-	char *uri, *local_path;
-	char *stripped_uri;
-	const char *last_slash, *link_name;
-	
-	if (item_uris == NULL) {
-		return;
-	}
-	
-	point.x = x;
-	point.y = y;
-		
-	uri_list = gnome_uri_list_extract_uris (item_uris);
-
-	for (node = uri_list; node != NULL; node = node->next) {
-		/* Most of what comes in here is not really URIs, but
-		 * rather paths that have a file: prefix in them.
-		 */
-		uri = eel_make_uri_from_half_baked_uri (node->data);
-
-		/* Make a link using the desktop file contents? */
-		local_path = gnome_vfs_get_local_path_from_uri (uri);
-		if (local_path != NULL) {
-			entry = gnome_desktop_entry_load (local_path);		
-			if (entry != NULL) {
-				/* FIXME: Handle name conflicts? */
-				nautilus_link_local_create_from_gnome_entry (entry, desktop_directory, &point);
-				gnome_desktop_entry_free (entry);
-			}
-			g_free (local_path);
-			if (entry != NULL) {
-				continue;
-			}
-		}
-		
-		/* Make a link from the URI alone. Generate the file
-		 * name by extracting the basename of the URI.
-		 */
-		/* FIXME: This should be using eel_uri_get_basename
-		 * instead of a "roll our own" solution.
-		 */
-		stripped_uri = eel_str_strip_trailing_chr (uri, '/');
-		last_slash = strrchr (stripped_uri, '/');
-		link_name = last_slash == NULL ? NULL : last_slash + 1;
-		
-		if (!eel_str_is_empty (link_name)) {
-			/* FIXME: Handle name conflicts? */
-			nautilus_link_local_create (desktop_directory, link_name,
-						    "gnome-http-url", uri,
-						    &point, NAUTILUS_LINK_GENERIC);
-		}
-		
-		g_free (stripped_uri);
-	}
-	
-	gnome_uri_list_free_strings (uri_list);
-}
-
 /* update_link_and_delete_copies
  * 
  * Look for a particular type of link on the desktop. If the right
@@ -1002,19 +942,17 @@ update_trash_link_and_delete_copies (void)
 {
 
 	/* Check for trash link */
-	if (update_link_and_delete_copies (nautilus_link_local_is_trash_link,
-					   TRASH_LINK_NAME,
-					   EEL_TRASH_URI)) {
-		return;
+	if (!update_link_and_delete_copies (nautilus_link_local_is_trash_link,
+					    TRASH_LINK_NAME,
+					    EEL_TRASH_URI)) {
+		nautilus_link_local_create (desktop_directory,
+					    TRASH_LINK_NAME,
+					    "trash-empty", 
+					    EEL_TRASH_URI,
+					    NULL,
+					    NAUTILUS_LINK_TRASH);
 	}
 
-	nautilus_link_local_create (desktop_directory,
-				    TRASH_LINK_NAME,
-				    "trash-empty", 
-				    EEL_TRASH_URI,
-				    NULL,
-				    NAUTILUS_LINK_TRASH);
-
 	/* Make sure link represents current trash state */
 	fm_desktop_icon_view_trash_state_changed_callback (nautilus_trash_monitor_get (),
 						   	   nautilus_trash_monitor_is_empty (),
@@ -1100,7 +1038,7 @@ desktop_icons_compare_callback (NautilusIconContainer *container,
 
 	if (category_a == category_b) {
 		return nautilus_file_compare_for_sort 
-			(file_a, file_b, NAUTILUS_FILE_SORT_BY_NAME, 
+			(file_a, file_b, NAUTILUS_FILE_SORT_BY_DISPLAY_NAME, 
 			 fm_directory_view_should_sort_directories_first (FM_DIRECTORY_VIEW (icon_view)), 
 			 FALSE);
 	}
@@ -1197,6 +1135,7 @@ update_disks_menu (FMDesktopIconView *view)
 	     element = element->next, ++index) {
 		volume = element->data;
 		
+
 		/* Determine human-readable name from mount path */
 		name = nautilus_volume_monitor_get_mount_name_for_display (nautilus_volume_monitor_get (), volume);
 		
@@ -1223,7 +1162,7 @@ update_disks_menu (FMDesktopIconView *view)
 			(view->details->ui,
 			 command_name,
 			 mount_or_unmount_removable_volume,
-			 mount_parameters_new (view, volume->mount_path),
+			 mount_parameters_new (view, nautilus_volume_get_mount_path (volume)),
 			 mount_parameters_free_wrapper);			 
 		g_free (command_name);
 		
