@@ -2127,6 +2127,14 @@ fm_icon_view_smooth_graphics_mode_changed (FMDirectoryView *directory_view)
 	fm_icon_view_update_smooth_graphics_mode (FM_ICON_VIEW (directory_view));
 }
 
+static void
+fm_icon_view_emblems_changed (FMDirectoryView *directory_view)
+{
+	g_assert (FM_IS_ICON_VIEW (directory_view));
+	
+	nautilus_icon_container_request_update_all (get_icon_container (FM_ICON_VIEW (directory_view)));	
+}
+
 static void
 default_sort_order_changed_callback (gpointer callback_data)
 {
@@ -2722,6 +2730,7 @@ fm_icon_view_initialize_class (FMIconViewClass *klass)
         fm_directory_view_class->image_display_policy_changed = fm_icon_view_image_display_policy_changed;
         fm_directory_view_class->merge_menus = fm_icon_view_merge_menus;
         fm_directory_view_class->smooth_graphics_mode_changed = fm_icon_view_smooth_graphics_mode_changed;
+        fm_directory_view_class->emblems_changed = fm_icon_view_emblems_changed;
         fm_directory_view_class->sort_directories_first_changed = fm_icon_view_sort_directories_first_changed;
         fm_directory_view_class->start_renaming_item = fm_icon_view_start_renaming_item;
         fm_directory_view_class->text_attribute_names_changed = fm_icon_view_text_attribute_names_changed;
