@@ -19,7 +19,7 @@
    write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
 
-   Authors: Darin Adler <darin@eazel.com>
+   Authors: Darin Adler <darin@bentspoon.com>
 */
 
 #include <config.h>
@@ -40,6 +40,7 @@
 #include <eel/eel-viewport.h>
 #include <eel/eel-wrap-table.h>
 #include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkdnd.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtkhbox.h>
@@ -127,6 +128,19 @@ typedef struct {
 	FMDirectoryView *directory_view;
 } StartupData;
 
+
+/* drag and drop definitions */
+
+enum {
+	TARGET_URI_LIST,
+	TARGET_GNOME_URI_LIST
+};
+
+static GtkTargetEntry target_table[] = {
+	{ "text/uri-list",  0, TARGET_URI_LIST },
+	{ "x-special/gnome-icon-list",  0, TARGET_GNOME_URI_LIST }
+};
+
 #define ERASE_EMBLEM_FILENAME	"erase.png"
 
 #define DIRECTORY_CONTENTS_UPDATE_INTERVAL	200 /* milliseconds */
@@ -146,6 +160,8 @@ static void directory_view_destroyed_callback     (FMDirectoryView         *view
 						   gpointer                 callback_data);
 static void select_image_button_callback          (GtkWidget               *widget,
 						   FMPropertiesWindow      *properties_window);
+static void set_icon_callback                     (const char* icon_path, 
+						   FMPropertiesWindow *properties_window);
 static void remove_image_button_callback          (GtkWidget               *widget,
 						   FMPropertiesWindow      *properties_window);
 static void remove_pending_file                   (StartupData             *data,
@@ -258,6 +274,77 @@ update_properties_window_icon (EelImage *image)
 	gdk_pixbuf_unref (pixbuf);
 }
 
+
+/* utility to test if a uri refers to a local image */
+static gboolean
+uri_is_local_image (const char *uri)
+{
+	GdkPixbuf *pixbuf;
+	char *image_path;
+	
+	image_path = gnome_vfs_get_local_path_from_uri (uri);
+	if (image_path == NULL) {
+		return FALSE;
+	}
+
+	pixbuf = gdk_pixbuf_new_from_file (image_path);
+	g_free (image_path);
+	
+	if (pixbuf == NULL) {
+		return FALSE;
+	}
+	gdk_pixbuf_unref (pixbuf);
+	return TRUE;
+}
+
+static void  
+fm_properties_window_drag_data_received (GtkWidget *widget, GdkDragContext *context,
+					 int x, int y,
+					 GtkSelectionData *selection_data,
+					 guint info, guint time)
+{
+	char **uris;
+	gboolean exactly_one;
+	EelImage *image;
+ 	GtkWindow *window; 
+
+	uris = g_strsplit (selection_data->data, "\r\n", 0);
+	exactly_one = uris[0] != NULL && uris[1] == NULL;
+
+	image = EEL_IMAGE (widget);
+ 	window = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (image)));
+
+
+	if (!exactly_one) {
+		eel_show_error_dialog (
+				       _("You can't assign more than one custom icon at a time! "
+					 "Please drag just one image to set a custom icon."), 
+				       _("More Than One Image"),
+				       window);
+	} else {		
+		if (uri_is_local_image (uris[0])) {			
+			set_icon_callback (gnome_vfs_get_local_path_from_uri (uris[0]), 
+					   FM_PROPERTIES_WINDOW (window));
+		} else {	
+			if (eel_is_remote_uri (uris[0])) {
+				eel_show_error_dialog (
+						       _("The file that you dropped is not local.  "
+							 "You can only use local images as custom icons."), 
+						       _("Local Images Only"),
+						       window);
+				
+			} else {
+				eel_show_error_dialog (
+						       _("The file that you dropped is not an image.  "
+							 "You can only use local images as custom icons."),
+						       _("Images Only"),
+						       window);
+			}
+		}		
+	}
+	g_strfreev (uris);
+}
+
 static GtkWidget *
 create_image_widget_for_file (NautilusFile *file)
 {
@@ -268,6 +355,16 @@ create_image_widget_for_file (NautilusFile *file)
 	
 	image = eel_image_new (NULL);
 
+	/* prepare the image to receive dropped objects to assign custom images */
+	gtk_drag_dest_set (GTK_WIDGET (image),
+			   GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP, 
+			   target_table, EEL_N_ELEMENTS (target_table),
+			   GDK_ACTION_COPY | GDK_ACTION_MOVE);
+
+	gtk_signal_connect( GTK_OBJECT (image), "drag_data_received",
+			    GTK_SIGNAL_FUNC (fm_properties_window_drag_data_received), NULL);
+
+
 	eel_image_set_pixbuf (EEL_IMAGE (image), pixbuf);
 
 	gdk_pixbuf_unref (pixbuf);
@@ -315,7 +412,7 @@ name_field_update_to_match_file (NautilusEntry *name_field)
 	 * an edit in progress. If the name hasn't changed (but some other
 	 * aspect of the file might have), then don't clobber changes.
 	 */
-	current_name = nautilus_file_get_name (file);
+	current_name = nautilus_file_get_display_name (file);
 	if (eel_strcmp (original_name, current_name) != 0) {
 		gtk_object_set_data_full (GTK_OBJECT (name_field),
 					  "original_name",
@@ -498,7 +595,7 @@ property_button_toggled (GtkToggleButton *button)
 	word = g_list_find_custom (keywords, name, (GCompareFunc) strcmp);
 	if (gtk_toggle_button_get_active (button)) {
 		if (word == NULL) {
-			keywords = g_list_append (keywords, g_strdup (name));
+			keywords = g_list_prepend (keywords, g_strdup (name));
 		}
 	} else {
 		if (word != NULL) {
@@ -518,7 +615,7 @@ update_properties_window_title (GtkWindow *window, NautilusFile *file)
 	g_assert (NAUTILUS_IS_FILE (file));
 	g_assert (GTK_IS_WINDOW (window));
 
-	name = nautilus_file_get_name (file);
+	name = nautilus_file_get_display_name (file);
 	title = g_strdup_printf (_("%s Properties"), name);
   	gtk_window_set_title (window, title);
 
@@ -716,7 +813,7 @@ activate_group_callback (GtkMenuItem *menu_item, FileNamePair *pair)
 		 pair->file,
 		 _("Cancel Group Change?"),
 		 _("Changing group"),
-		 NULL); /* FIXME bugzilla.eazel.com 2397: Parent this? */
+		 NULL); /* FIXME bugzilla.gnome.org 42397: Parent this? */
 	nautilus_file_set_group
 		(pair->file, pair->name,
 		 group_change_callback, NULL);
@@ -878,7 +975,7 @@ activate_owner_callback (GtkMenuItem *menu_item, FileNamePair *pair)
 		 pair->file,
 		 _("Cancel Owner Change?"),
 		 _("Changing owner"),
-		 NULL); /* FIXME bugzilla.eazel.com 2397: Parent this? */
+		 NULL); /* FIXME bugzilla.gnome.org 42397: Parent this? */
 	nautilus_file_set_owner
 		(pair->file, pair->name,
 		 owner_change_callback, NULL);
@@ -1364,7 +1461,7 @@ is_merged_trash_directory (NautilusFile *file)
 static gboolean
 should_show_custom_icon_buttons (FMPropertiesWindow *window) 
 {
-	/* FIXME bugzilla.eazel.com 5642:
+	/* FIXME bugzilla.gnome.org 45642:
 	 * Custom icons aren't displayed on the the desktop Trash icon, so
 	 * we shouldn't pretend that they work by showing them here.
 	 * When bug 5642 is fixed we can remove this case.
@@ -1404,7 +1501,7 @@ should_show_accessed_date (FMPropertiesWindow *window)
 static gboolean
 should_show_mime_type (FMPropertiesWindow *window) 
 {
-	/* FIXME bugzilla.eazel.com 5652:
+	/* FIXME bugzilla.gnome.org 45652:
 	 * nautilus_file_is_directory should return TRUE for special
 	 * trash directory, but doesn't. I could trivially fix this
 	 * with a check for is_merged_trash_directory here instead.
@@ -1484,7 +1581,7 @@ create_basic_page (FMPropertiesWindow *window)
 	/* Update name field initially before hooking up changed signal. */
 	name_field_update_to_match_file (NAUTILUS_ENTRY (name_field));
 
-/* FIXME bugzilla.eazel.com 2151:
+/* FIXME bugzilla.gnome.org 42151:
  * With this (and one place elsewhere in this file, not sure which is the
  * trouble-causer) code in place, bug 2151 happens (crash on quit). Since
  * we've removed Undo from Nautilus for now, I'm just ifdeffing out this
@@ -2050,7 +2147,7 @@ create_permissions_page (FMPropertiesWindow *window)
 		append_title_value_pair (page_table, _("Last Changed:"), file, "date_permissions");
 		
 	} else {
-		file_name = nautilus_file_get_name (file);
+		file_name = nautilus_file_get_display_name (file);
 		prompt_text = g_strdup_printf (_("The permissions of \"%s\" could not be determined."), file_name);
 		g_free (file_name);
 		add_prompt (GTK_VBOX (vbox), prompt_text, TRUE);
@@ -2061,7 +2158,7 @@ create_permissions_page (FMPropertiesWindow *window)
 static gboolean
 should_show_emblems (FMPropertiesWindow *window) 
 {
-	/* FIXME bugzilla.eazel.com 5643:
+	/* FIXME bugzilla.gnome.org 45643:
 	 * Emblems aren't displayed on the the desktop Trash icon, so
 	 * we shouldn't pretend that they work by showing them here.
 	 * When bug 5643 is fixed we can remove this case.
@@ -2132,6 +2229,8 @@ create_properties_window (StartupData *startup_data)
 	 * target file.
 	 */
 	attributes = nautilus_icon_factory_get_required_file_attributes ();
+	attributes = g_list_prepend (attributes,
+				     NAUTILUS_FILE_ATTRIBUTE_DISPLAY_NAME);
 	nautilus_file_monitor_add (window->details->original_file, window, attributes);
 	g_list_free (attributes);
 
@@ -2231,7 +2330,7 @@ create_properties_window_callback (NautilusFile *file, gpointer callback_data)
 
 	remove_pending_file (startup_data, FALSE, TRUE, TRUE);
 
-/* FIXME bugzilla.eazel.com 2151:
+/* FIXME bugzilla.gnome.org 42151:
  * See comment elsewhere in this file about bug 2151.
  */
 #ifdef UNDO_ENABLED
