@@ -47,7 +47,7 @@
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-string.h>
 #include <libnautilus-private/nautilus-undo-signal-handlers.h>
-#include <widgets/gimphwrapbox/gtkhwrapbox.h>
+#include "gtkhwrapbox.h"
 
 struct NautilusComplexSearchBarDetails {
 	GtkVBox *bar_container;
@@ -121,9 +121,8 @@ search_bar_criterion_type_changed_callback (GtkObject *old_criterion_object,
 	old_criterion_location = g_slist_find (bar->details->search_criteria,
 					       criterion);
 	old_criterion_location->data = new_criterion;
-	unattach_criterion_from_search_bar (bar,
-					    criterion);
-	gtk_object_destroy (GTK_OBJECT (criterion));
+	unattach_criterion_from_search_bar (bar, criterion);
+	gtk_object_sink (GTK_OBJECT (criterion));
 	nautilus_search_bar_criterion_show (new_criterion);
 	attach_criterion_to_search_bar (bar,
 					new_criterion,
@@ -371,7 +370,7 @@ nautilus_complex_search_bar_set_location (NautilusNavigationBar *navigation_bar,
 
 	bar = NAUTILUS_COMPLEX_SEARCH_BAR (navigation_bar);
 
-	/* FIXME bugzilla.eazel.com 2517: Not implemented. */
+	/* FIXME bugzilla.gnome.org 42517: Not implemented. */
 }
 
 void  
@@ -380,7 +379,7 @@ nautilus_complex_search_bar_queue_resize (NautilusComplexSearchBar      *bar)
 	GtkWidget *dock;
 
 	gtk_widget_queue_resize (bar->details->criteria_container);
-	/* FIXME bugzilla.eazel.com 3171:
+	/* FIXME bugzilla.gnome.org 43171:
 	 * (It is possible this comment is no longer correct due to
 	 * a change in the layout code)
 	 * We don't know why this line is needed here, but if it's removed
@@ -454,12 +453,18 @@ load_find_them_pixmap_widget (void)
 	GdkPixbuf *pixbuf;
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
+	GtkWidget *widget;
 	
 	pixbuf = gdk_pixbuf_new_from_file (NAUTILUS_PIXMAPDIR "/search.png");
-	if (pixmap != NULL) {
+	if (pixbuf != NULL) {
 		gdk_pixbuf_render_pixmap_and_mask (pixbuf, &pixmap, &mask, EEL_STANDARD_ALPHA_THRESHHOLD);
 		gdk_pixbuf_unref (pixbuf);
-		return gtk_pixmap_new (pixmap, mask);
+		widget = gtk_pixmap_new (pixmap, mask);
+
+		gdk_pixmap_unref (pixmap);
+		gdk_pixmap_unref (mask);
+ 
+		return widget;
 	} else {
 		return NULL;
 	}
