@@ -49,8 +49,8 @@
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-viewport.h>
 #include <eel/eel-xml-extensions.h>
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include <gtk/gtkcolorsel.h>
 #include <gtk/gtkdnd.h>
 #include <gtk/gtkentry.h>
@@ -642,7 +642,8 @@ make_drag_image (NautilusPropertyBrowser *property_browser, const char* file_nam
 {
 	GdkPixbuf *pixbuf, *orig_pixbuf;
 	char *image_file_name;
-
+	gboolean is_reset;
+	
 	image_file_name = g_strdup_printf ("%s/%s/%s",
 					   NAUTILUS_DATADIR,
 					   property_browser->details->category,
@@ -664,8 +665,10 @@ make_drag_image (NautilusPropertyBrowser *property_browser, const char* file_nam
 	
 	orig_pixbuf = gdk_pixbuf_new_from_file (image_file_name);
 	
+	is_reset = eel_strcmp (file_name, RESET_IMAGE_NAME) == 0;
+	
 	if (!strcmp(property_browser->details->category, "patterns")) {
-		pixbuf = nautilus_customization_make_pattern_chit (orig_pixbuf, property_browser->details->property_chit, TRUE);
+		pixbuf = nautilus_customization_make_pattern_chit (orig_pixbuf, property_browser->details->property_chit, TRUE, is_reset);
 	} else {
 		pixbuf = eel_gdk_pixbuf_scale_down_to_fit (orig_pixbuf, MAX_ICON_WIDTH, MAX_ICON_HEIGHT);
 		gdk_pixbuf_unref (orig_pixbuf);
@@ -710,7 +713,7 @@ make_color_drag_image (NautilusPropertyBrowser *property_browser, const char *co
 	
 	return nautilus_customization_make_pattern_chit (color_square, 
 							    property_browser->details->property_chit,
-							    trim_edges);	
+							    trim_edges, FALSE);	
 }
 
 /* this callback handles button presses on the category widget. It maintains the active state */
@@ -744,44 +747,13 @@ category_clicked_callback (GtkWidget *widget, char *category_name)
 	property_browser->details->selected_button = widget;
 }
 
-/* fetch the path of the xml file.  First, try to find it in the home directory, but it
-   we can't find it there, try the shared directory */
-   
-static char *
-get_xml_path (NautilusPropertyBrowser *property_browser)
-{
-	char *xml_path;
-	char *user_directory;
-
-	user_directory = nautilus_get_user_directory ();
-
-	/* first try the user's home directory */
-	xml_path = nautilus_make_path (user_directory,
-				       property_browser->details->path);
-	g_free (user_directory);
-	if (g_file_exists (xml_path)) {
-		return xml_path;
-	}
-	g_free (xml_path);
-	
-	/* next try the shared directory */
-	xml_path = nautilus_make_path (NAUTILUS_DATADIR,
-				       property_browser->details->path);
-	if (g_file_exists (xml_path)) {
-		return xml_path;
-	}
-	g_free (xml_path);
-
-	return NULL;
-}
-
 static xmlDocPtr
 read_browser_xml (NautilusPropertyBrowser *property_browser)
 {
 	char *path;
 	xmlDocPtr document;
 
-	path = get_xml_path (property_browser);
+	path = nautilus_get_data_file_path (property_browser->details->path);
 	if (path == NULL) {
 		return NULL;
 	}
@@ -1252,7 +1224,8 @@ emblem_keyword_valid (const char *keyword)
 
 	keyword_length = strlen (keyword);
 	for (index = 0; index < keyword_length; index++) {
-		if (!isalnum (keyword[index]) && !isspace (keyword[index])) {
+		if (!isalnum ((guchar) keyword[index])
+		    && !isspace ((guchar) keyword[index])) {
 			return FALSE;
 		}
 	}
@@ -1502,9 +1475,8 @@ element_clicked_callback (GtkWidget *image_table,
 	drag_types[0].target = property_browser->details->drag_type;
 	
 	/* treat the reset property in the colors section specially */	
-	if (strcmp (property_browser->details->drag_type, "application/x-color") == 0 &&
-		eel_strcmp (element_name, RESET_IMAGE_NAME) == 0) {
-		drag_types[0].target = "property/bgimage";	
+	if (eel_strcmp (element_name, RESET_IMAGE_NAME) == 0) {
+		drag_types[0].target = "x-special/gnome-reset-background";	
 	}
 	
 	target_list = gtk_target_list_new (drag_types, EEL_N_ELEMENTS (drag_types));	
@@ -1747,7 +1719,7 @@ add_reset_property (NautilusPropertyBrowser *property_browser)
 
 	reset_image_file_name = g_strdup_printf ("%s/%s/%s", NAUTILUS_DATADIR, "patterns", RESET_IMAGE_NAME);
 	reset_pixbuf = gdk_pixbuf_new_from_file (reset_image_file_name);
-	reset_chit = nautilus_customization_make_pattern_chit (reset_pixbuf, property_browser->details->property_chit, FALSE);
+	reset_chit = nautilus_customization_make_pattern_chit (reset_pixbuf, property_browser->details->property_chit, FALSE, TRUE);
 	
 	g_free (reset_image_file_name);
 
