@@ -36,7 +36,6 @@
 #include "nautilus-bookmarks-window.h"
 #include "nautilus-preferences-dialog.h"
 #include "nautilus-property-browser.h"
-#include "nautilus-services.h"
 #include "nautilus-signaller.h"
 #include "nautilus-switchable-navigation-bar.h"
 #include "nautilus-window-manage-views.h"
@@ -50,14 +49,15 @@
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-xml-extensions.h>
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include <gtk/gtkmain.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
 #include <libnautilus-private/nautilus-bonobo-extensions.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
@@ -100,8 +100,8 @@
 #define USER_MANUAL_URI		"help:nautilus-user-manual"
 #define QUICK_REFERENCE_URI	"help:nautilus-quick-reference"
 #define RELEASE_NOTES_URI	"help:nautilus-release-notes"
-#define CUSTOMER_SUPPORT_URI	"http://support.eazel.com"
 #define CUSTOMER_FEEDBACK_URI	"http://www.eazel.com/feedback.html"
+#define START_HERE_URI          "start-here:"
 
 static GtkWindow *bookmarks_window = NULL;
 
@@ -294,17 +294,6 @@ stop_button_callback (BonoboUIComponent *component,
 	nautilus_window_stop_loading (NAUTILUS_WINDOW (user_data));
 }
 
-static void
-services_button_callback (BonoboUIComponent *component, 
-			       gpointer user_data, 
-			       const char *verb)
-{
-	char *summary_uri;
-	summary_uri = nautilus_services_get_summary_uri ();
-	nautilus_window_go_to (NAUTILUS_WINDOW (user_data), summary_uri);
-	g_free (summary_uri);
-}
-
 static void
 edit_menu_undo_callback (BonoboUIComponent *component, 
 			 gpointer user_data, 
@@ -346,6 +335,15 @@ go_menu_home_callback (BonoboUIComponent *component,
 	nautilus_window_go_home (NAUTILUS_WINDOW (user_data));
 }
 
+static void
+go_menu_start_here_callback (BonoboUIComponent *component, 
+			     gpointer user_data, 
+			     const char *verb) 
+{
+	nautilus_window_go_to (NAUTILUS_WINDOW (user_data),
+			       START_HERE_URI);
+}
+
 static void
 forget_history_if_confirmed (NautilusWindow *window)
 {
@@ -685,15 +683,6 @@ help_menu_nautilus_release_notes_callback (BonoboUIComponent *component,
 	nautilus_window_go_to (NAUTILUS_WINDOW (user_data), RELEASE_NOTES_URI);
 }
 
-static void
-help_menu_support (BonoboUIComponent *component, 
-		       gpointer callback_data, 
-		       const char *verb)
-{
-	nautilus_window_go_to (NAUTILUS_WINDOW (callback_data),
-			       CUSTOMER_SUPPORT_URI);
-}
-
 static void
 help_menu_nautilus_feedback_callback (BonoboUIComponent *component, 
 			              gpointer user_data, 
@@ -1275,6 +1264,7 @@ nautilus_window_initialize_menus_part_1 (NautilusWindow *window)
 		BONOBO_UI_VERB ("Forward", go_menu_forward_callback),
 		BONOBO_UI_VERB ("Up", go_menu_up_callback),
 		BONOBO_UI_VERB ("Home", go_menu_home_callback),
+		BONOBO_UI_VERB ("Start Here", go_menu_start_here_callback),
 		BONOBO_UI_VERB ("Go to Location", go_menu_location_callback),
 		BONOBO_UI_VERB ("Forget History", go_menu_forget_history_callback),
 		BONOBO_UI_VERB ("Reload", view_menu_reload_callback),
@@ -1300,7 +1290,6 @@ nautilus_window_initialize_menus_part_1 (NautilusWindow *window)
 		BONOBO_UI_VERB ("Nautilus Manual", help_menu_nautilus_manual_callback),
 		BONOBO_UI_VERB ("Nautilus Quick Reference", help_menu_nautilus_quick_reference_callback),
 		BONOBO_UI_VERB ("Nautilus Release Notes", help_menu_nautilus_release_notes_callback),
-		BONOBO_UI_VERB ("Support", help_menu_support),
 		BONOBO_UI_VERB ("Nautilus Feedback", help_menu_nautilus_feedback_callback),
 
 		BONOBO_UI_VERB ("Switch to Beginner Level", user_level_menu_item_callback),
@@ -1313,21 +1302,12 @@ nautilus_window_initialize_menus_part_1 (NautilusWindow *window)
 		BONOBO_UI_VERB_END
 	};
 
-	BonoboUIVerb services_verbs [] = {
-		BONOBO_UI_VERB ("Services", services_button_callback),
-		BONOBO_UI_VERB_END
-	};
-
 	nautilus_window_ui_freeze (window);
 
 	bonobo_ui_component_freeze (window->details->shell_ui, NULL);
 
 	bonobo_ui_component_add_verb_list_with_data (window->details->shell_ui, verbs, window);
 
-	if (nautilus_services_are_enabled ()) {
-		bonobo_ui_component_add_verb_list_with_data (window->details->shell_ui, services_verbs, window);
-	}
-
         nautilus_window_update_show_hide_menu_items (window);
 
 	/* Keep track of user level changes to update the user level menu item icons */
