@@ -33,12 +33,10 @@
 #include "nautilus-application.h"
 #include "nautilus-bookmarks-window.h"
 #include "nautilus-main.h"
-#include "nautilus-services.h"
 #include "nautilus-sidebar.h"
 #include "nautilus-signaller.h"
 #include "nautilus-switchable-navigation-bar.h"
 #include "nautilus-window-manage-views.h"
-#include "nautilus-window-service-ui.h"
 #include "nautilus-zoom-control.h"
 #include <X11/Xatom.h>
 #include <bonobo/bonobo-exception.h>
@@ -69,6 +67,7 @@
 #include <libnautilus-private/nautilus-bonobo-extensions.h>
 #include <libnautilus-private/nautilus-drag-window.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
+#include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-horizontal-splitter.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
@@ -82,7 +81,7 @@
 #include <math.h>
 #include <sys/time.h>
 
-/* FIXME bugzilla.eazel.com 1243: 
+/* FIXME bugzilla.gnome.org 41243: 
  * We should use inheritance instead of these special cases
  * for the desktop window.
  */
@@ -93,7 +92,7 @@
 
 /* dock items */
 #define LOCATION_BAR_PATH	"/Location Bar"
-#define TOOLBAR_PATH           "/Toolbar"
+#define TOOLBAR_PATH            "/Toolbar"
 #define STATUS_BAR_PATH         "/status"
 #define MENU_BAR_PATH           "/menu"
 
@@ -117,29 +116,28 @@ static GList *history_list = NULL;
 static GdkPixmap *mini_icon_pixmap;
 static GdkBitmap *mini_icon_mask;
 
-static void nautilus_window_initialize_class       (NautilusWindowClass *klass);
-static void nautilus_window_initialize             (NautilusWindow      *window);
-static void nautilus_window_destroy                (GtkObject           *object);
-static void nautilus_window_set_arg                (GtkObject           *object,
-						    GtkArg              *arg,
-						    guint                arg_id);
-static void nautilus_window_get_arg                (GtkObject           *object,
-						    GtkArg              *arg,
-						    guint                arg_id);
-static int  nautilus_window_key_press_event	   (GtkWidget		*widget,
-						    GdkEventKey		*event);
-static void nautilus_window_size_request           (GtkWidget           *widget,
-						    GtkRequisition      *requisition);
-static void nautilus_window_realize                (GtkWidget           *widget);
-static void update_sidebar_panels_from_preferences (NautilusWindow      *window);
-static void sidebar_panels_changed_callback        (gpointer             user_data);
-static void nautilus_window_show                   (GtkWidget           *widget);
-static void cancel_view_as_callback                (NautilusWindow      *window);
-static void real_add_current_location_to_history_list (NautilusWindow   *window);
+static void nautilus_window_initialize_class          (NautilusWindowClass *klass);
+static void nautilus_window_initialize                (NautilusWindow      *window);
+static void nautilus_window_destroy                   (GtkObject           *object);
+static void nautilus_window_set_arg                   (GtkObject           *object,
+						       GtkArg              *arg,
+						       guint                arg_id);
+static void nautilus_window_get_arg                   (GtkObject           *object,
+						       GtkArg              *arg,
+						       guint                arg_id);
+static void nautilus_window_size_request              (GtkWidget           *widget,
+						       GtkRequisition      *requisition);
+static void nautilus_window_realize                   (GtkWidget           *widget);
+static void update_sidebar_panels_from_preferences    (NautilusWindow      *window);
+static void sidebar_panels_changed_callback           (gpointer             user_data);
+static void nautilus_window_show                      (GtkWidget           *widget);
+static void nautilus_window_unrealize                 (GtkWidget           *widget);
+static void cancel_view_as_callback                   (NautilusWindow      *window);
+static void real_add_current_location_to_history_list (NautilusWindow      *window);
 
 EEL_DEFINE_CLASS_BOILERPLATE (NautilusWindow,
-				   nautilus_window,
-				   BONOBO_TYPE_WINDOW)
+			      nautilus_window,
+			      BONOBO_TYPE_WINDOW)
 
 static void
 unref_mini_icon (void)
@@ -166,6 +164,7 @@ nautilus_window_initialize_class (NautilusWindowClass *klass)
 	object_class->set_arg = nautilus_window_set_arg;
 	
 	widget_class->show = nautilus_window_show;
+	widget_class->unrealize = nautilus_window_unrealize;
 	
 	gtk_object_add_arg_type ("NautilusWindow::app_id",
 				 GTK_TYPE_STRING,
@@ -178,7 +177,6 @@ nautilus_window_initialize_class (NautilusWindowClass *klass)
 	
 	widget_class->realize = nautilus_window_realize;
 	widget_class->size_request = nautilus_window_size_request;
-	widget_class->key_press_event = nautilus_window_key_press_event;
 
 	klass->add_current_location_to_history_list
 		= real_add_current_location_to_history_list;
@@ -198,10 +196,10 @@ nautilus_window_initialize_class (NautilusWindowClass *klass)
 }
 
 static void
-nautilus_window_for_each_sidebar_panel (const char *name,
-					const char *iid,
-					const char *preference_key,
-					gpointer callback_data) 
+add_sidebar_panel_callback (const char *name,
+			    const char *iid,
+			    const char *preference_key,
+			    gpointer callback_data) 
 {
 	g_return_if_fail (name != NULL);
 	g_return_if_fail (iid != NULL);
@@ -209,9 +207,9 @@ nautilus_window_for_each_sidebar_panel (const char *name,
 	g_return_if_fail (NAUTILUS_IS_WINDOW (callback_data));
 	
 	eel_preferences_add_callback_while_alive (preference_key,
-						       sidebar_panels_changed_callback,
-						       callback_data,
-						       GTK_OBJECT (callback_data));
+						  sidebar_panels_changed_callback,
+						  callback_data,
+						  GTK_OBJECT (callback_data));
 }
 
 static void
@@ -222,7 +220,7 @@ nautilus_window_initialize (NautilusWindow *window)
 	gtk_quit_add_destroy (1, GTK_OBJECT (window));
 
 	/* Keep track of changes in enabled state of sidebar panels */
-	nautilus_sidebar_for_each_panel (nautilus_window_for_each_sidebar_panel, window);
+	nautilus_sidebar_for_each_panel (add_sidebar_panel_callback, window);
 
 	/* Keep the main event loop alive as long as the window exists */
 	nautilus_main_event_loop_register (GTK_OBJECT (window));
@@ -352,7 +350,7 @@ nautilus_window_clear_status (gpointer callback_data)
 
 	nautilus_window_ui_freeze (window);
 
-	/* FIXME bugzilla.eazel.com 3597:
+	/* FIXME bugzilla.gnome.org 43597:
 	 * Should pass "" or NULL here. This didn't work, then did, now doesn't again.
 	 * When this is fixed in Bonobo we should change this line.
 	 */
@@ -684,11 +682,6 @@ nautilus_window_constructed (NautilusWindow *window)
 			       "nautilus");
 	bonobo_ui_component_thaw (window->details->shell_ui, NULL);
 	
-	/* Load the services part of the user interface too if desired. */
-	if (nautilus_services_are_enabled ()) {
-		nautilus_window_install_service_ui (window);
-	}
-
 	/* set up location bar */
 	location_bar_box = gtk_hbox_new (FALSE, GNOME_PAD);
 	gtk_container_set_border_width (GTK_CONTAINER (location_bar_box), GNOME_PAD_SMALL);
@@ -736,7 +729,7 @@ nautilus_window_constructed (NautilusWindow *window)
 	
 	gtk_widget_show (location_bar_box);
 	
-	/* FIXME bugzilla.eazel.com 1243: 
+	/* FIXME bugzilla.gnome.org 41243: 
 	 * We should use inheritance instead of these special cases
 	 * for the desktop window.
 	 */
@@ -748,33 +741,36 @@ nautilus_window_constructed (NautilusWindow *window)
 		window->content_hbox = nautilus_horizontal_splitter_new ();
 		panel = E_PANED (window->content_hbox);
 		
-		/* FIXME bugzilla.eazel.com 1245: Saved in pixels instead of in %? */
-		/* FIXME bugzilla.eazel.com 1245: No reality check on the value? */
+		/* FIXME bugzilla.gnome.org 41245: Saved in pixels instead of in %? */
+		/* FIXME bugzilla.gnome.org 41245: No reality check on the value? */
 		sidebar_width = eel_preferences_get_integer (NAUTILUS_PREFERENCES_SIDEBAR_WIDTH);
 		e_paned_set_position (E_PANED (window->content_hbox), sidebar_width);
 	}
 	gtk_widget_show (window->content_hbox);
 	bonobo_window_set_contents (BONOBO_WINDOW (window), window->content_hbox);
 	
-	/* set up the sidebar */
-	window->sidebar = nautilus_sidebar_new ();
-	
-	/* FIXME bugzilla.eazel.com 1243: 
+	/* FIXME bugzilla.gnome.org 41243: 
 	 * We should use inheritance instead of these special cases
 	 * for the desktop window.
 	 */
         if (!NAUTILUS_IS_DESKTOP_WINDOW (window)) {
+		/* set up the sidebar */
+		window->sidebar = nautilus_sidebar_new ();
 		gtk_widget_show (GTK_WIDGET (window->sidebar));
 		gtk_signal_connect (GTK_OBJECT (window->sidebar), "location_changed",
 				    go_to_callback, window);
 		e_paned_pack1 (E_PANED (window->content_hbox),
 			       GTK_WIDGET (window->sidebar),
-			       FALSE, FALSE);
+			       FALSE, TRUE);
+#if 0
+		bonobo_ui_engine_add_sync (bonobo_window_get_ui_engine (BONOBO_WINDOW (window)),
+					   sidebar_sync);
+#endif
 	}
 	
 	bonobo_ui_component_freeze (window->details->shell_ui, NULL);
 
-	/* FIXME bugzilla.eazel.com 1243: 
+	/* FIXME bugzilla.gnome.org 41243: 
 	 * We should use inheritance instead of these special cases
 	 * for the desktop window.
 	 */
@@ -788,7 +784,7 @@ nautilus_window_constructed (NautilusWindow *window)
 		nautilus_bonobo_set_hidden (window->details->shell_ui,
 					    MENU_BAR_PATH, TRUE);
 
-		/* FIXME bugzilla.eazel.com 4752:
+		/* FIXME bugzilla.gnome.org 44752:
 		 * If we ever get the unsigned math errors in
 		 * gtk_menu_item_size_allocate fixed this can be removed.
 		 */
@@ -903,13 +899,43 @@ free_stored_viewers (NautilusWindow *window)
 	window->details->extra_viewer = NULL;
 }
 
-static void 
-nautilus_window_destroy (GtkObject *object)
+static void
+nautilus_window_unrealize (GtkWidget *widget)
 {
 	NautilusWindow *window;
 	CORBA_Environment ev;
 	Bonobo_PropertyBag property_bag;
 	
+	window = NAUTILUS_WINDOW (widget);
+
+	/* Get rid of the throbber explicitly before it self-destructs
+	 * (which it will do when the control frame goes away.
+	 */
+	if (window->throbber != CORBA_OBJECT_NIL) {
+		CORBA_exception_init (&ev);
+		property_bag = Bonobo_Control_getProperties (window->throbber, &ev);
+		if (!BONOBO_EX (&ev) && property_bag != CORBA_OBJECT_NIL) {	
+			bonobo_event_source_client_remove_listener
+				(property_bag,
+				 window->details->throbber_location_change_request_listener_id,
+				 &ev);
+			bonobo_object_release_unref (property_bag, NULL);	
+		}
+		CORBA_exception_free (&ev);
+
+		bonobo_object_release_unref (window->throbber, NULL);
+
+		window->throbber = CORBA_OBJECT_NIL;
+	}
+
+	EEL_CALL_PARENT (GTK_WIDGET_CLASS, unrealize, (widget));
+}
+
+static void 
+nautilus_window_destroy (GtkObject *object)
+{
+	NautilusWindow *window;
+	
 	window = NAUTILUS_WINDOW (object);
 
 	/* Handle the part of destroy that's private to the view
@@ -918,8 +944,7 @@ nautilus_window_destroy (GtkObject *object)
 	nautilus_window_manage_views_destroy (window);
 
 	/* Get rid of all callbacks. */
-
-	cancel_view_as_callback (window);
+	nautilus_window_set_viewed_file (window, NULL);
 	nautilus_window_remove_bookmarks_menu_callback (window);
 	nautilus_window_remove_go_menu_callback (window);
 	nautilus_window_toolbar_remove_theme_callback (window);
@@ -963,27 +988,15 @@ nautilus_window_destroy (GtkObject *object)
 		bonobo_object_unref (BONOBO_OBJECT (window->details->ui_container));
 	}
 
-	if (window->throbber != CORBA_OBJECT_NIL) {
-		CORBA_exception_init (&ev);
-		property_bag = Bonobo_Control_getProperties (window->throbber, &ev);
-		if (!BONOBO_EX (&ev) && property_bag != CORBA_OBJECT_NIL) {	
-			bonobo_event_source_client_remove_listener
-				(property_bag,
-				 window->details->throbber_location_change_request_listener_id,
-				 &ev);
-			bonobo_object_release_unref (property_bag, NULL);	
-		}
-		CORBA_exception_free (&ev);
-
-		bonobo_object_release_unref (window->throbber, NULL);
-	}
 	if (window->details->location_change_at_idle_id != 0) {
 		gtk_idle_remove (window->details->location_change_at_idle_id);
 	}
 
+	g_free (window->details->title);
+	
 	g_free (window->details);
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (GTK_OBJECT (window)));
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void
@@ -1062,38 +1075,6 @@ nautilus_window_realize (GtkWidget *widget)
 	nautilus_window_update_launcher (widget->window);
 }
 
-static int
-nautilus_window_key_press_event (GtkWidget *widget,
-		 		 GdkEventKey *event)
-{
-	NautilusWindow *window;
-	gboolean handled;
-
-	window = NAUTILUS_WINDOW (widget);
-
-	handled = FALSE;
-
-	/* Make Control-= an alternate shortcut for Zoom, since on U.S. keyboards
-	 * (at least) Control-+ requires typing the shift key, which is annoying.
-	 * For some reason I don't understand, if I don't test for GDK_plus here,
-	 * Control + Shift + (+/=) on a US keyboard doesn't activate the command,
-	 * though it does if this function is removed.
-	 */
-	if (event->keyval == GDK_equal || event->keyval == GDK_plus) {
-		if ((event->state & (GDK_CONTROL_MASK | GDK_MOD1_MASK)) == GDK_CONTROL_MASK) {
-			nautilus_window_zoom_in (window);
-			handled = TRUE;
-		}
-	}
-
-	if (!handled) {
-		handled = EEL_CALL_PARENT_WITH_RETURN_VALUE
-			(GTK_WIDGET_CLASS, key_press_event, (widget, event));
-	}
-
-	return handled;
-}
-
 static void
 nautilus_window_size_request (GtkWidget		*widget,
 			      GtkRequisition	*requisition)
@@ -1430,7 +1411,7 @@ chose_component_callback (NautilusViewIdentifier *identifier, gpointer callback_
 		nautilus_window_set_content_view (window, identifier);
 	}
 	
-	/* FIXME bugzilla.eazel.com 1334: There should be some global
+	/* FIXME bugzilla.gnome.org 41334: There should be some global
 	 * way to signal that the file type associations have changed,
 	 * so that the places that display these lists can react. For
 	 * now, hardwire this case, which is the most obvious one by
@@ -1488,19 +1469,19 @@ view_as_menu_choose_view_callback (GtkWidget *widget, gpointer data)
 static void
 refresh_stored_viewers (NautilusWindow *window)
 {
-	GList *components;
-        GList *node;
+	GList *components, *node, *viewers;
 	NautilusViewIdentifier *identifier;
 
-        free_stored_viewers (window);
-
         components = nautilus_mime_get_short_list_components_for_file (window->details->viewed_file);
+	viewers = NULL;
         for (node = components; node != NULL; node = node->next) {
         	identifier = nautilus_view_identifier_new_from_content_view (node->data);
-        	window->details->short_list_viewers = 
-        		g_list_append (window->details->short_list_viewers, identifier);
+        	viewers = g_list_prepend (viewers, identifier);
         }
 	gnome_vfs_mime_component_list_free (components);
+
+        free_stored_viewers (window);
+	window->details->short_list_viewers = g_list_reverse (viewers);
 }
 
 static void
@@ -1605,6 +1586,7 @@ nautilus_window_add_sidebar_panel (NautilusWindow *window,
 {
 	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 	g_return_if_fail (NAUTILUS_IS_VIEW_FRAME (sidebar_panel));
+	g_return_if_fail (NAUTILUS_IS_SIDEBAR (window->sidebar));
 	g_return_if_fail (g_list_find (window->sidebar_panels, sidebar_panel) == NULL);
 	
 	nautilus_sidebar_add_panel (window->sidebar, sidebar_panel);
@@ -2000,7 +1982,7 @@ nautilus_window_set_content_view_widget (NautilusWindow *window,
 		 */
 		nautilus_window_ui_update (window);
 
-		/* FIXME bugzilla.eazel.com 1243: 
+		/* FIXME bugzilla.gnome.org 41243: 
 		 * We should use inheritance instead of these special cases
 		 * for the desktop window.
 		 */
@@ -2042,11 +2024,7 @@ update_sidebar_panels_from_preferences (NautilusWindow *window)
 
 	g_assert (NAUTILUS_IS_WINDOW (window));
 
-	/* FIXME bugzilla.eazel.com 1243: 
-	 * We should use inheritance instead of these special cases
-	 * for the desktop window.
-	 */
-	if (NAUTILUS_IS_DESKTOP_WINDOW (window)) {
+	if (window->sidebar == NULL) {
 		return;
 	}
 
@@ -2146,8 +2124,11 @@ nautilus_window_toolbar_showing (NautilusWindow *window)
 void 
 nautilus_window_hide_sidebar (NautilusWindow *window)
 {
+	if (window->sidebar == NULL) {
+		return;
+	}
 	gtk_widget_hide (GTK_WIDGET (window->sidebar));
-	if (window->content_hbox != NULL && !NAUTILUS_IS_DESKTOP_WINDOW (window)) {
+	if (window->content_hbox != NULL) {
 		e_paned_set_position (E_PANED (window->content_hbox), 0);
 	}
 	nautilus_window_update_show_hide_menu_items (window);
@@ -2158,9 +2139,12 @@ nautilus_window_show_sidebar (NautilusWindow *window)
 {
 	GtkWidget *widget;
 
+	if (window->sidebar == NULL) {
+		return;
+	}
 	widget = GTK_WIDGET (window->sidebar);
 	gtk_widget_show (widget);
-	if (window->content_hbox != NULL && !NAUTILUS_IS_DESKTOP_WINDOW (window)) {
+	if (window->content_hbox != NULL) {
 		e_paned_set_position (E_PANED (window->content_hbox), widget->allocation.width);
 		/* Make sure sidebar is not in collapsed form also */
 		nautilus_horizontal_splitter_expand (NAUTILUS_HORIZONTAL_SPLITTER (window->content_hbox));
@@ -2171,7 +2155,9 @@ nautilus_window_show_sidebar (NautilusWindow *window)
 gboolean
 nautilus_window_sidebar_showing (NautilusWindow *window)
 {
-	return GTK_WIDGET_VISIBLE (window->sidebar);
+	g_return_val_if_fail (NAUTILUS_IS_WINDOW (window), FALSE);
+
+	return window->sidebar != NULL && GTK_WIDGET_VISIBLE (window->sidebar);
 }
 
 void 
@@ -2281,13 +2267,28 @@ void
 nautilus_window_set_viewed_file (NautilusWindow *window,
 				 NautilusFile *file)
 {
+	GList *attributes;
+
 	if (window->details->viewed_file == file) {
 		return;
 	}
 
 	nautilus_file_ref (file);
+
 	cancel_view_as_callback (window);
 	cancel_chose_component_callback (window);
+
+	if (window->details->viewed_file != NULL) {
+		nautilus_file_monitor_remove (window->details->viewed_file,
+					      window);
+	}
+
+	if (file != NULL) {
+		attributes = g_list_prepend (NULL, NAUTILUS_FILE_ATTRIBUTE_DISPLAY_NAME);
+		nautilus_file_monitor_add (file, window, attributes);
+		g_list_free (attributes);
+	}
+
 	nautilus_file_unref (window->details->viewed_file);
 	window->details->viewed_file = file;
 }
